==> field_manager_python_client-4.5.60-py3-none-any.whl: field_manager_python_client/api/piezometers/update_piezometer_model_projects_project_id_piezometers_models_model_id_put.py <==
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.piezometer_model import PiezometerModel
from ...models.piezometer_model_update import PiezometerModelUpdate
from ...types import Response


def _get_kwargs(
    project_id: str,
    model_id: UUID,
    *,
    body: PiezometerModelUpdate,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": f"/projects/{project_id}/piezometers/models/{model_id}",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    if response.status_code == 200:
        response_200 = PiezometerModel.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
    body: PiezometerModelUpdate,
) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    """Update Piezometer Model

     Update piezometer model

    Args:
        project_id (str):
        model_id (UUID):
        body (PiezometerModelUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, PiezometerModel]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        model_id=model_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
    body: PiezometerModelUpdate,
) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    """Update Piezometer Model

     Update piezometer model

    Args:
        project_id (str):
        model_id (UUID):
        body (PiezometerModelUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, PiezometerModel]
    """

    return sync_detailed(
        project_id=project_id,
        model_id=model_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
    body: PiezometerModelUpdate,
) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    """Update Piezometer Model

     Update piezometer model

    Args:
        project_id (str):
        model_id (UUID):
        body (PiezometerModelUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, PiezometerModel]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        model_id=model_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
    body: PiezometerModelUpdate,
) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    """Update Piezometer Model

     Update piezometer model

    Args:
        project_id (str):
        model_id (UUID):
        body (PiezometerModelUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, PiezometerModel]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            model_id=model_id,
            client=client,
            body=body,
        )
    ).parsed

==> field_manager_python_client-4.6.37-py3-none-any.whl: field_manager_python_client/api/piezometers/update_piezometer_model_projects_project_id_piezometers_models_model_id_put.py <==
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.piezometer_model import PiezometerModel
from ...models.piezometer_model_update import PiezometerModelUpdate
from ...types import Response


def _get_kwargs(
    project_id: str,
    model_id: UUID,
    *,
    body: PiezometerModelUpdate,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": f"/projects/{project_id}/piezometers/models/{model_id}",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    if response.status_code == 200:
        response_200 = PiezometerModel.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
    body: PiezometerModelUpdate,
) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    """Update Piezometer Model

     Update piezometer model

    Args:
        project_id (str):
        model_id (UUID):
        body (PiezometerModelUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, PiezometerModel]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        model_id=model_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
    body: PiezometerModelUpdate,
) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    """Update Piezometer Model

     Update piezometer model

    Args:
        project_id (str):
        model_id (UUID):
        body (PiezometerModelUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, PiezometerModel]
    """

    return sync_detailed(
        project_id=project_id,
        model_id=model_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
    body: PiezometerModelUpdate,
) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    """Update Piezometer Model

     Update piezometer model

    Args:
        project_id (str):
        model_id (UUID):
        body (PiezometerModelUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, PiezometerModel]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        model_id=model_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
    body: PiezometerModelUpdate,
) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    """Update Piezometer Model

     Update piezometer model

    Args:
        project_id (str):
        model_id (UUID):
        body (PiezometerModelUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, PiezometerModel]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            model_id=model_id,
            client=client,
            body=body,
        )
    ).parsed
